# cimlib

Python library for parsing CIM files

## Funcionamiento

Para probar correr `test.py`. (Cuidado con el path del archivo que se intenta parsear). Tambien se puede imprimir en json sin guardarlo usando la funcion `get_json()` en vez de `save_json()`.
